Example: Simple Feature Demonstration — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »
- Examples »

# Example: Simple Feature Demonstration

This program is an example of writing some of the features of the XlsxWriter module.

Code:

    ##############################################################################
    #
    # A simple example of some of the features of the XlsxWriter Python module.
    #
    # Copyright 2013, John McNamara, jmcnamara@cpan.org
    #
    from xlsxwriter.workbook import Workbook

    # Create an new Excel file and add a worksheet.
    workbook = Workbook('demo.xlsx')
    worksheet = workbook.add_worksheet()

    # Widen the first column to make the text clearer.
    worksheet.set_column('A:A', 20)

    # Add a bold format to use to highlight cells.
    bold = workbook.add_format({'bold': 1})

    # Write some simple text.
    worksheet.write('A1', 'Hello')

    # Text with formatting.
    worksheet.write('A2', 'World', bold)

    # Write some numbers, with row/column notation.
    worksheet.write(2, 0, 123)
    worksheet.write(3, 0, 123.456)

    workbook.close()

Notes:

- This example includes the use of cell formatting via the The Format Class.
- Strings and numbers can be written with the same worksheet `write()` method.
- Data can be written to cells using Row-Column notation or ‘A1’ style notation, see Working with Cell Notation.

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »
- Examples »